@@ -39,27 +39,27 @@ def test_if_exception_type_multiple():
 
 
 def test_if_transient_error():
-    assert retry.if_transient_error(exceptions.InternalServerError(''))
-    assert retry.if_transient_error(exceptions.TooManyRequests(''))
-    assert not retry.if_transient_error(exceptions.InvalidArgument(''))
+    assert retry.if_transient_error(exceptions.InternalServerError(""))
+    assert retry.if_transient_error(exceptions.TooManyRequests(""))
+    assert not retry.if_transient_error(exceptions.InvalidArgument(""))
 
 
 # Make uniform return half of its maximum, which will be the calculated
 # sleep time.
-@mock.patch('random.uniform', autospec=True, side_effect=lambda m, n: n/2.0)
+@mock.patch("random.uniform", autospec=True, side_effect=lambda m, n: n / 2.0)
 def test_exponential_sleep_generator_base_2(uniform):
-    gen = retry.exponential_sleep_generator(
-        1, 60, multiplier=2)
+    gen = retry.exponential_sleep_generator(1, 60, multiplier=2)
 
     result = list(itertools.islice(gen, 8))
     assert result == [1, 2, 4, 8, 16, 32, 60, 60]
 
 
-@mock.patch('time.sleep', autospec=True)
+@mock.patch("time.sleep", autospec=True)
 @mock.patch(
-    'google.api_core.datetime_helpers.utcnow',
+    "google.api_core.datetime_helpers.utcnow",
     return_value=datetime.datetime.min,
-    autospec=True)
+    autospec=True,
+)
 def test_retry_target_success(utcnow, sleep):
     predicate = retry.if_exception_type(ValueError)
     call_count = [0]
@@ -77,39 +77,40 @@ def test_retry_target_success(utcnow, sleep):
     sleep.assert_has_calls([mock.call(0), mock.call(1)])
 
 
-@mock.patch('time.sleep', autospec=True)
+@mock.patch("time.sleep", autospec=True)
 @mock.patch(
-    'google.api_core.datetime_helpers.utcnow',
+    "google.api_core.datetime_helpers.utcnow",
     return_value=datetime.datetime.min,
-    autospec=True)
+    autospec=True,
+)
 def test_retry_target_w_on_error(utcnow, sleep):
     predicate = retry.if_exception_type(ValueError)
-    call_count = {'target': 0}
+    call_count = {"target": 0}
     to_raise = ValueError()
 
     def target():
-        call_count['target'] += 1
-        if call_count['target'] < 3:
+        call_count["target"] += 1
+        if call_count["target"] < 3:
             raise to_raise
         return 42
 
     on_error = mock.Mock()
 
-    result = retry.retry_target(
-        target, predicate, range(10), None, on_error=on_error)
+    result = retry.retry_target(target, predicate, range(10), None, on_error=on_error)
 
     assert result == 42
-    assert call_count['target'] == 3
+    assert call_count["target"] == 3
 
     on_error.assert_has_calls([mock.call(to_raise), mock.call(to_raise)])
     sleep.assert_has_calls([mock.call(0), mock.call(1)])
 
 
-@mock.patch('time.sleep', autospec=True)
+@mock.patch("time.sleep", autospec=True)
 @mock.patch(
-    'google.api_core.datetime_helpers.utcnow',
+    "google.api_core.datetime_helpers.utcnow",
     return_value=datetime.datetime.min,
-    autospec=True)
+    autospec=True,
+)
 def test_retry_target_non_retryable_error(utcnow, sleep):
     predicate = retry.if_exception_type(ValueError)
     exception = TypeError()
@@ -122,12 +123,11 @@ def test_retry_target_non_retryable_error(utcnow, sleep):
     sleep.assert_not_called()
 
 
-@mock.patch('time.sleep', autospec=True)
-@mock.patch(
-    'google.api_core.datetime_helpers.utcnow', autospec=True)
+@mock.patch("time.sleep", autospec=True)
+@mock.patch("google.api_core.datetime_helpers.utcnow", autospec=True)
 def test_retry_target_deadline_exceeded(utcnow, sleep):
     predicate = retry.if_exception_type(ValueError)
-    exception = ValueError('meep')
+    exception = ValueError("meep")
     target = mock.Mock(side_effect=exception)
     # Setup the timeline so that the first call takes 5 seconds but the second
     # call takes 6, which puts the retry over the deadline.
@@ -135,21 +135,21 @@ def test_retry_target_deadline_exceeded(utcnow, sleep):
         # The first call to utcnow establishes the start of the timeline.
         datetime.datetime.min,
         datetime.datetime.min + datetime.timedelta(seconds=5),
-        datetime.datetime.min + datetime.timedelta(seconds=11)]
+        datetime.datetime.min + datetime.timedelta(seconds=11),
+    ]
 
     with pytest.raises(exceptions.RetryError) as exc_info:
         retry.retry_target(target, predicate, range(10), deadline=10)
 
     assert exc_info.value.cause == exception
-    assert exc_info.match('Deadline of 10.0s exceeded')
-    assert exc_info.match('last exception: meep')
+    assert exc_info.match("Deadline of 10.0s exceeded")
+    assert exc_info.match("last exception: meep")
     assert target.call_count == 2
 
 
 def test_retry_target_bad_sleep_generator():
-    with pytest.raises(ValueError, match='Sleep generator'):
-        retry.retry_target(
-            mock.sentinel.target, mock.sentinel.predicate, [], None)
+    with pytest.raises(ValueError, match="Sleep generator"):
+        retry.retry_target(mock.sentinel.target, mock.sentinel.predicate, [], None)
 
 
 class TestRetry(object):
@@ -197,8 +197,7 @@ class TestRetry(object):
 
     def test_with_delay(self):
         retry_ = retry.Retry()
-        new_retry = retry_.with_delay(
-            initial=1, maximum=2, multiplier=3)
+        new_retry = retry_.with_delay(initial=1, maximum=2, multiplier=3)
         assert retry_ is not new_retry
         assert new_retry._initial == 1
         assert new_retry._maximum == 2
@@ -206,50 +205,50 @@ class TestRetry(object):
 
     def test___str__(self):
         retry_ = retry.Retry()
-        assert re.match((
-            r'<Retry predicate=<function.*?if_exception_type.*?>, '
-            r'initial=1.0, maximum=60.0, multiplier=2.0, deadline=120.0>'),
-            str(retry_))
+        assert re.match(
+            (
+                r"<Retry predicate=<function.*?if_exception_type.*?>, "
+                r"initial=1.0, maximum=60.0, multiplier=2.0, deadline=120.0>"
+            ),
+            str(retry_),
+        )
 
-    @mock.patch('time.sleep', autospec=True)
+    @mock.patch("time.sleep", autospec=True)
     def test___call___and_execute_success(self, sleep):
         retry_ = retry.Retry()
-        target = mock.Mock(spec=['__call__'], return_value=42)
+        target = mock.Mock(spec=["__call__"], return_value=42)
         # __name__ is needed by functools.partial.
-        target.__name__ = 'target'
+        target.__name__ = "target"
 
         decorated = retry_(target)
         target.assert_not_called()
 
-        result = decorated('meep')
+        result = decorated("meep")
 
         assert result == 42
-        target.assert_called_once_with('meep')
+        target.assert_called_once_with("meep")
         sleep.assert_not_called()
 
     # Make uniform return half of its maximum, which will be the calculated
     # sleep time.
-    @mock.patch(
-        'random.uniform', autospec=True, side_effect=lambda m, n: n/2.0)
-    @mock.patch('time.sleep', autospec=True)
+    @mock.patch("random.uniform", autospec=True, side_effect=lambda m, n: n / 2.0)
+    @mock.patch("time.sleep", autospec=True)
     def test___call___and_execute_retry(self, sleep, uniform):
 
-        on_error = mock.Mock(spec=['__call__'], side_effect=[None])
-        retry_ = retry.Retry(
-            predicate=retry.if_exception_type(ValueError),
-        )
+        on_error = mock.Mock(spec=["__call__"], side_effect=[None])
+        retry_ = retry.Retry(predicate=retry.if_exception_type(ValueError))
 
-        target = mock.Mock(spec=['__call__'], side_effect=[ValueError(), 42])
+        target = mock.Mock(spec=["__call__"], side_effect=[ValueError(), 42])
         # __name__ is needed by functools.partial.
-        target.__name__ = 'target'
+        target.__name__ = "target"
 
         decorated = retry_(target, on_error=on_error)
         target.assert_not_called()
 
-        result = decorated('meep')
+        result = decorated("meep")
 
         assert result == 42
         assert target.call_count == 2
-        target.assert_has_calls([mock.call('meep'), mock.call('meep')])
+        target.assert_has_calls([mock.call("meep"), mock.call("meep")])
         sleep.assert_called_once_with(retry_._initial)
         assert on_error.call_count == 1
